@@ -1,6 +1,6 @@
 import json
 import logging
-from typing import Awaitable, Dict
+from typing import Any, Awaitable
 
 from aiohttp import web
 from linkedin_messaging import LinkedInMessaging
@@ -14,7 +14,7 @@ class ProvisioningAPI:
     log: TraceLogger = logging.getLogger("mau.web.provisioning")
     app: web.Application
 
-    def __init__(self, shared_secret: str) -> None:
+    def __init__(self, shared_secret: str):
         self.app = web.Application()
         self.shared_secret = shared_secret
         self.app.router.add_get("/api/whoami", self.status)
@@ -23,7 +23,7 @@ class ProvisioningAPI:
         self.app.router.add_post("/api/logout", self.logout)
 
     @property
-    def _acao_headers(self) -> Dict[str, str]:
+    def _acao_headers(self) -> dict[str, str]:
         return {
             "Access-Control-Allow-Origin": "*",
             "Access-Control-Allow-Headers": "Authorization, Content-Type",
@@ -31,7 +31,7 @@ class ProvisioningAPI:
         }
 
     @property
-    def _headers(self) -> Dict[str, str]:
+    def _headers(self) -> dict[str, str]:
         return {
             **self._acao_headers,
             "Content-Type": "application/json",
@@ -72,7 +72,7 @@ class ProvisioningAPI:
         except web.HTTPError as e:
             return e
 
-        data = {
+        data: dict[str, Any] = {
             "permissions": user.permission_level,
             "mxid": user.mxid,
             "linkedin": None,
@@ -104,10 +104,6 @@ class ProvisioningAPI:
             data["JSESSIONID"] = data["JSESSIONID"].strip('"')
             client.session.cookie_jar.update_cookies(data)
             client.session.headers["csrf-token"] = data["JSESSIONID"]
-            self.log.debug(data)
-            for c in client.session.cookie_jar:
-                self.log.debug(c)
-            self.log.debug(client.session.headers)
             await user.on_logged_in(client)
         except Exception:
             self.log.exception("Failed to log in", exc_info=True)
